@@ -144,7 +144,7 @@ sub scan
     $self->logger->debug("Command: $cmd");
 
     $self->command_line($cmd);
-    $self->logger->error('masscan not found') && croak if (!$binary || $binary !~ m{masscan$}xmi);
+    $self->logger->fatal('masscan not found') && croak if (!$binary || $binary !~ m{masscan$}xmi);
 
     $self->logger->info('Attempting to run command');
     my $scan = $self->_run_cmd($cmd . " -oJ $fstore");
@@ -155,7 +155,7 @@ sub scan
     }
     else
     {
-        croak $self->logger->error("Command has failed: $scan->{stderr} " . 'Ensure root or sudo permissions');
+        $self->logger->error("Command has failed: $scan->{stderr} " . 'Ensure root or sudo permissions');
     }
 
     return ($scan->{success}) ? 1 : 0;
@@ -168,6 +168,8 @@ sub scan_results
     my $sres = $self->_from_json($self->_slurp_file($self->scan_results_file));
     my %up_hosts;
 
+    $self->logger->warn("No results") if (!$sres);
+
     map{$up_hosts{$_->{ip}} = 1}($sres->@*);
     $self->logger->info('Collating scan results');
 
@@ -217,11 +219,19 @@ sub _slurp_file
 
     $self->logger->debug("Slurping up file: $path");
 
-    open(my $fh, '<', $path) || die $!;
-        my $data = $self->_slurp($fh);
-    close($fh);
+    try
+    {
+        open(my $fh, '<', $path) || die $!;
+            my $data = $self->_slurp($fh);
+        close($fh);
 
-    return $data;
+        return $data;
+    }
+    catch
+    {
+        $self->logger->warn("$!. " . 'Most likely scan was not successful.');
+        return;
+    }
 }
 
 # internal method _slurp
@@ -521,7 +531,7 @@ Masscan::Scanner - A Perl module which helps in using the masscan port scanner.
 
 =head1 VERSION
 
-version 20200328.173827
+version 20200328.204213
 
 =head1 SYNOPSIS
 
